abacusai.project_feature_group_schema_version — AbacusAI documentation

# abacusai.project_feature_group_schema_version

## Classes

`ProjectFeatureGroupSchemaVersion` | A version of a schema

## Module Contents

class abacusai.project_feature_group_schema_version.ProjectFeatureGroupSchemaVersion(client, schemaVersion=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A version of a schema

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - schemaVersion (id) – The unique identifier of a schema version.

  schema_version = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict